@@ -327,7 +327,7 @@ class RpcExchangerClient:
         self.check_authorized()
         if chat_id not in self._chat_list:
             raise ChatNotJoinedError()
-        return await self._rpc.chat.get_all_permission(chat_id=chat_id)
+        return await self._rpc.chat.get_all_user_permission(chat_id=chat_id)
 
     def __aiter__(self) -> RpcExchangerClient:
         return self
